%% Oxygen Consumption: Box, Hunter and Hunter (1978)
close all;
clear all;
clc;

%% Data
Oxygen_demand = [8.5 10.9 19 16 15.8 20];
Time_days = [1 2 3 4 5 7];

%% Model Function
modelfun = @(b,x)b(1)*(1 - exp(-b(2)*x));

%% Initial Condition
initial_condition = [100 0.1];

%% Nonlinear Model and Prediction Data
mdl = fitnlm(Time_days,Oxygen_demand,modelfun,initial_condition);

time_observation = linspace(0, 10, 20)';
predicted_value = predict(mdl,time_observation);

%% Results Analysis
figure(1)
plot(Time_days, Oxygen_demand, 'co');
hold on
plot(Time_days, mdl.Fitted, 'r*')
plot(time_observation,predicted_value)
xlabel('Time [days]', 'Interpreter', 'latex')
ylabel('[$O_2$] [mg/l]', 'Interpreter', 'latex')
set(gcf,'color','white');
legend('Concentration', 'Predicted Concentration', 'Model Fit', 'Interpreter', 'latex')

%% Display Results
disp('%----------------------------------------%')
disp('Residuals Value')
disp([num2str(mdl.Residuals.Standardized)])
disp('%----------------------------------------%')
disp('Estimate Value')
disp(['b1:  ' num2str(mdl.Coefficients.Estimate(1))])
disp(['b2:  ' num2str(mdl.Coefficients.Estimate(2))])
disp('%----------------------------------------%')
disp('Coefficient of Determination')
disp(['Rsquare Ordinary:  ' num2str(mdl.Rsquared.Ordinary)])
disp(['Rsquare Adjusted:  ' num2str(mdl.Rsquared.Adjusted)])
disp('%----------------------------------------%')